@@ -1,6 +1,8 @@
-from .base import Simulation, LTFArray
+from .base import Simulation, LTFArray, XORPUF
 
 from .bistable import XORBistableRingPUF, BistableRingPUF
 
 from .delay import XORArbiterPUF, XORFeedForwardArbiterPUF, ArbiterPUF, LightweightSecurePUF, RandomTransformationPUF, \
-    PermutationPUF, InterposePUF
+    PermutationPUF, InterposePUF, FeedForwardArbiterPUF
+
+from .optical import IntegratedOpticalPUF
